pro sxi_sswdb_l1q, queue_days=queue_days, parent=parent, $
   goesn=goesn, no_purge=no_purge, no_delete=no_delete, $
   force_recopy=force_recopy, purge_only=purge_only
;
;+
;   Name: sxi_sswdb_l1q
;
;   Purpose: populate recent data queue in $SSWDB, optionally cleanup old
;
;   Input Parameters:
;      
;
;   Keyword Parameters
;      queue_days - number of days to consider (and optionally delete older)
;      parent     - top directory - default is $SSWDB/goes/sxigNN/l1q
;      goesn      - GOES sat# (default is 12, the first)
;      no_delete  - (switch) if set, don't do the cleanup/delete of older
;        no_purge   - (switch) synonym for no_delete
;        purge_only - (switch) if set, only do purge ; skip copy
;
;
;   History:
;      5-Feb-2003 - for quicklook/spaceweather apps.
;     12-Feb-2003 - check file_sizes first for speed, add /FORCE_RECOPY
;                   to override (passed to sxi_copy via /CLOBBER if set)
;
;   Calls:
;      sxi_files, sxi_copy, and usual ssw suspects
;


if n_elements(queue_days) eq 0 then queue_days=1           ; number of days in Q
if n_elements(goesn) eq 0 then goesn=12               ; 1st come 1st served
sgoesn=strtrim(goesn,2)                               ; string equiv
force_recopy=keyword_set(force_recopy)                ; avoid uneeded sxi_copy
                                                      ; calls  
no_purge=keyword_set(no_purge) or keyword_set(no_delete)
purge_only=keyword_set(purge_only)

if n_elements(parent) eq 0 then parent= $
   concat_dir(concat_dir(concat_dir('$SSWDB','goes'),'sxig'+sgoesn),'l1q')


sxifiles=sxi_files(anytim(reltime(days=-(queue_days)),/date_only,/ecs), $
                   anytim(reltime(hour=1),/ecs),/ngdc,/full_path)

sxifiles=sxifiles(uniq(sxifiles))
sxifiles=reverse(sxifiles)

sxiserv=sxi_server(path=path)

if not purge_only then begin
if not force_recopy then begin 
   outfiles=str_replace(sxifiles,path,parent)
   fsizes=file_size(outfiles)   
   needss=where(fsizes lt 1074240,sscnt)
   if sscnt eq 0 then begin 
      box_message,'All files copied already - use /FORCE_RECOPY to refresh'
      return
   endif else box_message,'Need to copy ' + strtrim(sscnt,2) + ' files...'
   sxifiles=sxifiles(needss)
endif 
outdirs=concat_dir(parent,strextract(sxifiles,path+'/','SXI'))
udirs=uniq(outdirs)

; create non-existant subdirectories
for i=0,n_elements(udirs)-1 do $  
   spawn,['mkdir','-p',outdirs(udirs(i))],/noshell


; copy files (sxi_copy includes caching to avoid recopies)

for i=0,n_elements(sxifiles)-1 do begin 
   box_message,['Copying>> ' + sxifiles(i) ,$
                'To>> ' + outdirs(i)]
   sxi_copy,sxifiles(i),out_dir=outdirs(i), clobber=force_recopy
   
endfor

endif else box_message,'PURGE_ONLY'
if not no_purge then begin 
   tgrid=timegrid(reltime(days=-7),reltime(days=-(queue_days+1)),$
      /day,out='ecs',/date_only)
   pdirs=concat_dir(parent,tgrid)
   for i=0,n_elements(pdirs)-1 do begin 
      box_message,'Purging: ' + pdirs(i)
      spawn,['rm','-rf',pdirs(i)],/noshell
   endfor
endif

return
end
   

